OC.L10N.register(
    "settings",
    {
    "Invalid request" : "داواکارى نادروستە",
    "All" : "هەمووی",
    "Enable" : "چالاککردن",
    "None" : "هیچ",
    "Login" : "چوونەژوورەوە",
    "Encryption" : "نهێنیکردن",
    "Server address" : "ناونیشانی ڕاژه",
    "Cancel" : "لابردن",
    "Email" : "ئیمه‌یل",
    "Password" : "وشەی تێپەربو",
    "New password" : "وشەی نهێنی نوێ",
    "Name" : "ناو",
    "Username" : "ناوی به‌کارهێنه‌ر",
    "Admin" : "به‌ڕێوه‌به‌ری سه‌ره‌كی",
    "Error" : "هه‌ڵه",
    "Share" : "هاوبەشی کردن",
    "Add" : "زیادکردن"
},
"nplurals=2; plural=(n != 1);");
